@@ -5,7 +5,10 @@ discretePlot <- function(x, by, scale=c("frequency", "percent"), xlab=deparse(su
         y <- as.vector(table(x))
         if (scale == "percent") y <- 100*y/sum(y)
         x <- sort(unique(x))
-        plot(x, y, type="h", xlab=xlab, ylab=ylab, main=main, xlim=xlim, ylim=ylim)
+        plot(x, y, type="h", xlab=xlab, ylab=ylab, main=main, xlim=xlim, ylim=ylim,
+             axes=FALSE, frame.plot=TRUE)
+        axis(2)
+        axis(1, at=x)
         points(x, y, pch=16)
         abline(h=0, col="gray")
     }
